@@ -10,18 +10,15 @@ import typing_extensions
 
 from typeguard import check_type
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_elasticache._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-lambda-elasticachememcached",
-    "1.181.1",
+    "2.17.0",
     __name__[0:-6],
-    "aws-lambda-elasticachememcached@1.181.1.jsii.tgz",
+    "aws-lambda-elasticachememcached@2.17.0.jsii.tgz",
 )
 
 __all__ = [
